@@ -277,7 +277,7 @@ def getNewEventsFromGoogle(pid, localSource, remoteSource, lastSync, \
 
 		if (fullday == 1):
 			tz = time.timezone
-			if (time.daylight):
+			if (time.localtime(start_time).tm_isdst):
 				tz = time.altzone
 			start_time += tz
 			end_time += tz
